"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var botbuilder_logging_1 = require("botbuilder-logging");
var events_1 = require("events");
var BotCallLogger = /** @class */ (function () {
    function BotCallLogger(documentClient, options) {
        this.events = new events_1.EventEmitter();
        var documentWriter = new botbuilder_logging_1.DocumentDbWriter(documentClient, options.documents);
        var blobWriter = options.blobs ? new botbuilder_logging_1.AzureBlobWriter(options.blobs.blobService, options.blobs.options) : null;
        this.writer = new botbuilder_logging_1.BotLogWriter(documentWriter, blobWriter, options);
    }
    BotCallLogger.prototype.botbuilder = function (session, next) {
        var _this = this;
        this.writer.enqueue(session, function (err) { return _this.done(err); });
        next();
    };
    BotCallLogger.prototype.receive = function (event, next) {
        var _this = this;
        this.writer.enqueue(event, function (err) { return _this.done(err); });
        next();
    };
    BotCallLogger.prototype.send = function (event, next) {
        var _this = this;
        this.writer.enqueue(event, function (err) { return _this.done(err); });
        next();
    };
    BotCallLogger.prototype.done = function (err) {
        if (err) {
            this.events.emit('error', err);
        }
    };
    return BotCallLogger;
}());
exports.BotCallLogger = BotCallLogger;
//# sourceMappingURL=bot-call-logger.js.map